summaryrefslogtreecommitdiffstats
path: root/qtsharp/src/examples/tutorials/t2.cs
diff options
context:
space:
mode:
Diffstat (limited to 'qtsharp/src/examples/tutorials/t2.cs')
-rw-r--r--qtsharp/src/examples/tutorials/t2.cs10
1 files changed, 5 insertions, 5 deletions
diff --git a/qtsharp/src/examples/tutorials/t2.cs b/qtsharp/src/examples/tutorials/t2.cs
index 84af5a37..5dbe07d1 100644
--- a/qtsharp/src/examples/tutorials/t2.cs
+++ b/qtsharp/src/examples/tutorials/t2.cs
@@ -9,16 +9,16 @@ public class Example {
public static int Main (String[] args)
{
- TTQApplication a = new TTQApplication (args);
+ TQApplication a = new TQApplication (args);
- TTQPushButton quit = new TTQPushButton ("Quit", null);
+ TQPushButton quit = new TQPushButton ("Quit", null);
// In C++, the second parameter is 0 (null pointer)
quit.Resize (75, 30);
- quit.SetFont (new TTQFont ("Times", 18, TTQFont.Weight.Bold));
- // In C++, TTQFont::Bold is sufficient
+ quit.SetFont (new TQFont ("Times", 18, TQFont.Weight.Bold));
+ // In C++, TQFont::Bold is sufficient
- TTQObject.Connect ( quit, QtSupport.TQT_SIGNAL ("clicked()"), a, QtSupport.TQT_SLOT ("Quit()") );
+ TQObject.Connect ( quit, QtSupport.TQT_SIGNAL ("clicked()"), a, QtSupport.TQT_SLOT ("Quit()") );
// TQT_SIGNAL and TQT_SLOT are static functions of QtSupport
a.SetMainWidget (quit);